@@ -2,7 +2,7 @@ import appdirs
 import os
 from urllib.parse import urlparse
 from dagshub import __version__
-import requests.utils
+from httpx._client import USER_AGENT
 
 HOST_KEY = "DAGSHUB_CLIENT_HOST"
 DEFAULT_HOST = "https://dagshub.com"
@@ -16,6 +16,8 @@ TOKENS_CACHE_SCHEMA_VERSION = "1"
 DAGSHUB_USER_TOKEN_KEY = "DAGSHUB_USER_TOKEN"
 DAGSHUB_USERNAME_KEY = "DAGSHUB_USERNAME"
 DAGSHUB_PASSWORD_KEY = "DAGSHUB_PASSWORD"
+HTTP_TIMEOUT_KEY = "DAGSHUB_HTTP_TIMEOUT"
+DAGSHUB_QUIET_KEY = "DAGSHUB_QUIET"
 
 parsed_host = urlparse(os.environ.get(HOST_KEY, DEFAULT_HOST))
 hostname = parsed_host.hostname
@@ -28,5 +30,11 @@ token = os.environ.get(DAGSHUB_USER_TOKEN_KEY)
 username = os.environ.get(DAGSHUB_USERNAME_KEY)
 password = os.environ.get(DAGSHUB_PASSWORD_KEY)
 custom_user_agent_suffix = f" dagshub-client-python/{__version__}"
-requests_headers = {"user-agent": requests.utils.default_user_agent() + custom_user_agent_suffix}
+requests_headers = {"user-agent": USER_AGENT + custom_user_agent_suffix}
+http_timeout = os.environ.get(HTTP_TIMEOUT_KEY, 30)
 REPO_INFO_URL = "api/v1/repos/{owner}/{reponame}"
+
+quiet = bool(os.environ.get(DAGSHUB_QUIET_KEY, False))
+
+# DVC config templates
+CONFIG_GITIGNORE = "/config.local\n/tmp\n/cache"
